@@ -126,12 +126,17 @@ sub delete {
 __PACKAGE__->meta->make_immutable;
 
 1;
-__END__
+
+
 =pod
 
 =head1 NAME
 
-Catalyst::Model::REST - REST model class for Catalyst
+Catalyst::Model::REST
+
+=head1 VERSION
+
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -150,11 +155,14 @@ Catalyst::Model::REST - REST model class for Catalyst
 		...
 	}
 
-
 =head1 DESCRIPTION
 
 This model class makes REST connectivety easy.
 
+=head1 NAME
+
+Catalyst::Model::REST - REST model class for Catalyst
+
 =head1 METHODS
 
 =head2 new
@@ -185,3 +193,19 @@ Copyright 2010 Kaare Rasmussen, all rights reserved.
 This library is free software; you can redistribute it and/or modify it under the same terms as 
 Perl itself, either Perl version 5.8.8 or, at your option, any later version of Perl 5 you may 
 have available.
+
+=head1 AUTHOR
+
+Kaare Rasmussen <kaare at cpan dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Kaare Rasmussen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
