@@ -18,7 +18,18 @@ has 'data' => (
 __PACKAGE__->meta->make_immutable;
 
 1;
-__END__
+
+
+=pod
+
+=head1 NAME
+
+Catalyst::Model::REST::Response
+
+=head1 VERSION
+
+version 0.10
+
 =head1 NAME
 
 Catalyst::Model::REST::Response - Response class for REST
@@ -54,3 +65,19 @@ Copyright 2010 Kaare Rasmussen, all rights reserved.
 This library is free software; you can redistribute it and/or modify it under the same terms as 
 Perl itself, either Perl version 5.8.8 or, at your option, any later version of Perl 5 you may 
 have available.
+
+=head1 AUTHOR
+
+Kaare Rasmussen <kaare at cpan dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Kaare Rasmussen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
