@@ -37,4 +37,28 @@ sub content_type {
 	return $self->type;
 }
 
-1;
\ No newline at end of file
+1;
+__END__
+=pod
+
+=head1 NAME
+
+Catalyst::Model::REST::Serializer
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Kaare Rasmussen <kaare at cpan dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Kaare Rasmussen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
